Commit 59261a8f1d6e3b8e67428e2d8e7ce04bb58fce98

Con Kolivas 2013-03-02T21:40:55

Merge pull request #393 from kanoi/main api -> drv

diff --git a/cgminer.c b/cgminer.c
index 1caac24..7dcf204 100644
--- a/cgminer.c
+++ b/cgminer.c
@@ -6658,8 +6658,8 @@ static void noop_thread_enable(struct thr_info __maybe_unused *thr)
 #define noop_flush_work noop_reinit_device
 #define noop_queue_full noop_get_stats
 
-/* Fill missing driver api functions with noops */
-void fill_device_api(struct cgpu_info *cgpu)
+/* Fill missing driver drv functions with noops */
+void fill_device_drv(struct cgpu_info *cgpu)
 {
 	struct device_drv *drv = cgpu->drv;
 
@@ -6713,7 +6713,7 @@ void enable_device(struct cgpu_info *cgpu)
 		gpu_threads += cgpu->threads;
 	}
 #endif
-	fill_device_api(cgpu);
+	fill_device_drv(cgpu);
 
 	rwlock_init(&cgpu->qlock);
 	cgpu->queued_work = NULL;